import smllib.sml
from smllib.builder import SmlObjBuilder


class SmlGetListResponseBuilder(SmlObjBuilder[smllib.sml.SmlGetListResponse]):
    BUILDS = smllib.sml.SmlGetListResponse
